#ifndef STRINGCOMPLETER_H
#define STRINGCOMPLETER_H

#include <QObject>
#include <QString>
#include <QStringList>

/**
  StringCompleter
  This is a simple clean class where a stringlist is send to (setData(...)).
  Then once search(...) is called with a needle, it will search through the stringlist and emit any matches it finds.
  Once done, it emits a stringlist with all matches.
*/
class StringCompleter : public QObject
{
    Q_OBJECT
public:
    explicit StringCompleter(QObject *parent = 0);

    /**
      set the data to search through for hits
     */
    void setData(const QStringList& list);

    /**
      return the data that was set using setData (useless function?)
     */
    const QStringList& data();

    /**
      search for a given needle in the given QStringList (set by setData).
      This function will continue to search till there is nothing more to search
      though or till the user calls the abort function

      emits searchHit on hit
      emits searchCompleted with a stringlist of matches. Empty list means no matches.
     */
    void search(const QString& needle);

signals:
    void searchCompleted(const QStringList& results, const QString& needle);
    void searchHit(const QString& result);

public slots:

private: // variables
    QStringList m_data;
    QStringList m_results;
    QString m_lastSearchNeedle;
};

#endif // STRINGCOMPLETER_H
